.. _core_classes:

Core classes
############

.. automodule:: maicos.core

.. toctree::
   :titlesonly:
   :maxdepth: 4
   :caption: Core classes

   base/index
   planar/index
   cylinder/index
   sphere/index
